@@ -6,6 +6,18 @@
 @CREATED    : November 10, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: element.c,v $
+ * Revision 6.11  2006/09/01 16:33:49  jharlap
+ * fixed bug in Acr_nema that caused dump_acr_nema to skip all elements with element number 0x0010 when it should only have skipped 0x7fe0,0x0010.
+ *
+ * Revision 6.10  2006/04/09 15:28:40  bert
+ * Add functions acr_get_element_double_array and acr_create_element_double
+ *
+ * Revision 6.9  2006/03/10 19:22:56  bert
+ * Update to conversion/Acr_nema/element.c for value printing
+ *
+ * Revision 6.8  2005/07/14 15:56:56  bert
+ * Print raw byte data when dumping fields with unknown value representations and sizes other than 2 or 4. (ported from 1.X)
+ *
  * Revision 6.7.2.2  2005/06/06 20:48:14  bert
  * Print raw byte data when dumping fields with unknown value representations and sizes other than 2 or 4.
  *
@@ -1176,6 +1188,29 @@ Acr_Element acr_create_element_long(Acr_Element_Id elid,
    return create_element_mem(elid, ACR_VR_UL, sizeof(value), (void *) &value);
 }
 
+/* ----------------------------- MNI Header -----------------------------------
+@NAME       : acr_create_element_double
+@INPUT      : elid
+              nvalues
+              values
+@OUTPUT     : (none)
+@RETURNS    : Pointer to element structure
+@DESCRIPTION: Creates an acr-nema element structure containing an array of 
+              doubles.
+@METHOD     : 
+@GLOBALS    : 
+@CALLS      : 
+@CREATED    : April 8, 2006 (Bert Vincent)
+@MODIFIED   : 
+---------------------------------------------------------------------------- */
+Acr_Element acr_create_element_double(Acr_Element_Id elid,
+                                      int nvalues,
+                                      double *values)
+{
+   return create_element_mem(elid, ACR_VR_FD, (ACR_SIZEOF_DOUBLE * nvalues), 
+                             values);
+}
+
 /* ----------------------------- MNI Header -----------------------------------
 @NAME       : acr_create_element_numeric
 @INPUT      : elid
@@ -1198,12 +1233,17 @@ Acr_Element acr_create_element_numeric(Acr_Element_Id elid,
    char string[256];
    Acr_Element element;
 
-   (void) sprintf(string, "%.15g", value);
-   element = acr_create_element_string(elid, string);
-   if (elid->vr_code == ACR_VR_UNKNOWN)
-      acr_set_element_vr(element, ACR_VR_DS);
+   if (elid->vr_code == ACR_VR_FD) {
+       element = create_element_mem(elid, ACR_VR_FD, sizeof(value), 
+                                    (void *) &value);
+   }
+   else {
+       (void) sprintf(string, "%.15g", value);
+       element = acr_create_element_string(elid, string);
+       if (elid->vr_code == ACR_VR_UNKNOWN)
+           acr_set_element_vr(element, ACR_VR_DS);
+   }
    return element;
-
 }
 
 /* ----------------------------- MNI Header -----------------------------------
@@ -1423,6 +1463,50 @@ long acr_get_element_short_array(Acr_Element element, long max_values,
    return nvalues;
 }
 
+/* ----------------------------- MNI Header -----------------------------------
+@NAME       : acr_get_element_double_array
+@INPUT      : element
+              max_values - maximum number of values to return
+@OUTPUT     : values - array of values found
+@RETURNS    : Number of values found
+@DESCRIPTION: Gets an array of doubles from an element structure. If the 
+              number of values in the element is greater than max_values, 
+              then only max_values values are extracted, but the total
+              number of values in the element is returned.
+@METHOD     : 
+@GLOBALS    : 
+@CALLS      : 
+@CREATED    : April 8, 2006 (Bert Vincent)
+@MODIFIED   : 
+---------------------------------------------------------------------------- */
+long acr_get_element_double_array(Acr_Element element, long max_values, 
+                                  double values[])
+{
+   long nvalues;
+
+   /* Check VR of element */
+   switch (acr_get_element_vr(element)) {
+   case ACR_VR_FD:
+   case ACR_VR_UNKNOWN:
+      break;
+   default:
+      return (long) 0;
+   }
+
+   /* Get number of values in element */
+   nvalues = acr_get_element_length(element) / ACR_SIZEOF_DOUBLE;
+
+   /* Check the maximum number of values */
+   if (max_values > nvalues) max_values = nvalues;
+
+   /* Get the data */
+   acr_get_double(acr_get_element_byte_order(element),
+                  max_values, acr_get_element_data(element), values);
+
+   /* Return the number of values in the structure */
+   return nvalues;
+}
+
 /* ----------------------------- MNI Header -----------------------------------
 @NAME       : acr_element_numeric_array_separator
 @INPUT      : character - character to add to list or EOF if not adding 
@@ -1536,6 +1620,88 @@ int acr_get_element_numeric_array(Acr_Element element,
    return nvalues;
 }
 
+static void 
+maybe_print_as_string(FILE *file_pointer, Acr_Element cur_element,
+                      int element_length, int done_already)
+{
+    char *string;
+    char *copy;
+    int string_length;
+    int printable = 0;
+    int i;
+    int j;
+
+    string = acr_get_element_string(cur_element);
+    string_length = element_length;
+    while ((string_length > 0) && (string[string_length-1] == '\0')) {
+        string_length--;
+    }
+
+    /* Print string if short enough and is printable */
+    if (element_length > 0 &&
+		  !(acr_get_element_group(cur_element) == 0x7fe0 &&
+        acr_get_element_element(cur_element) == 0x0010)) {
+        copy = malloc(string_length + 1);
+        printable = (string_length > 0);
+        for (i=0; i < string_length; i++) {
+            if (! isprint((int) string[i])) {
+                printable = FALSE;
+                copy[i] = ' ';
+            }
+            else if ((string[i] == '\n') ||
+                     (string[i] == '\r') ||
+                     (string[i] == '\f'))
+                copy[i] = ' ';
+            else
+                copy[i] = string[i];
+        }
+        copy[i] = '\0';
+
+        if (printable) {
+            (void) fprintf(file_pointer, " string = \"%s\"", copy);
+        }
+        else if (!done_already) {
+            /* If unknown length print as a series of bytes.
+             */
+            string = acr_get_element_data(cur_element);
+            fprintf(file_pointer, " byte = ");
+            if (element_length < 1000) {
+                for (i = 0; i < element_length; i++) {
+                    fprintf(file_pointer, "%#x", 
+                            (unsigned char)string[i]);
+                    if (i != element_length - 1) {
+                        fprintf(file_pointer, ", ");
+                    }
+                }
+            }
+            else {
+                fprintf(file_pointer, "\n");
+                for (i = 0; i < element_length; i += 16) {
+                    for (j = 0; j < 16; j++) {
+                            if (i + j < element_length) {
+                                fprintf(file_pointer, "%02x ", 
+                                        (unsigned char)string[i+j]);
+                            }
+                            else {
+                                fprintf(file_pointer, "   ");
+                            }
+                        }
+                        fprintf(file_pointer, "| ");
+                        for (j = 0; j < 16; j++) {
+                            if (i + j < element_length) {
+                                int c = (unsigned char)string[i+j];
+                                fprintf(file_pointer, "%c", 
+                                        isprint(c) ? c : '.');
+                            }
+                        }
+                        fprintf(file_pointer, "\n");
+                    }
+            }
+        }
+        free(copy);
+    }
+}
+
 /* ----------------------------- MNI Header -----------------------------------
 @NAME       : acr_dump_element_list
 @INPUT      : file_pointer - where output should go
@@ -1555,10 +1721,7 @@ void acr_dump_element_list(FILE *file_pointer,
 #define INDENT_AMOUNT 3
    Acr_Element cur_element;
    long element_length;
-   long string_length;
-   int printable;
    int i;
-   char *string, *copy;
    static int current_indent_level = 0;
    Acr_VR_Type vr_code;
 
@@ -1577,12 +1740,14 @@ void acr_dump_element_list(FILE *file_pointer,
          (void) putc((int) ' ', file_pointer);
       }
 
+      element_length = acr_get_element_length(cur_element);
+
       /* Print the element id */
       (void) fprintf(file_pointer, 
                      "0x%04x  0x%04x  length = %d ",
                      acr_get_element_group(cur_element),
                      acr_get_element_element(cur_element),
-                     (int) acr_get_element_length(cur_element));
+                     (int) element_length);
 
       if (_acr_name_proc != NULL) {
           char *name_ptr;
@@ -1630,6 +1795,8 @@ void acr_dump_element_list(FILE *file_pointer,
             break;
          case ACR_VR_OB:
          case ACR_VR_OW:
+            maybe_print_as_string(file_pointer, cur_element,
+                                  element_length, 0);
             break;
          default:
             (void) fprintf(file_pointer, "value = \"%s\"",
@@ -1641,7 +1808,6 @@ void acr_dump_element_list(FILE *file_pointer,
       else {
          int done_already = 0;
 
-         element_length = acr_get_element_length(cur_element);
          switch (element_length) {
          case ACR_SIZEOF_SHORT:
             (void) fprintf(file_pointer, " short = %d (0x%04x)",
@@ -1657,48 +1823,8 @@ void acr_dump_element_list(FILE *file_pointer,
             break;
          }
 
-         string = acr_get_element_string(cur_element);
-         string_length = element_length;
-         while ((string_length > 0) && (string[string_length-1] == '\0')) {
-            string_length--;
-         }
-
-         /* Print string if short enough and is printable */
-         if (element_length > 0) {
-            copy = malloc(string_length + 1);
-            printable = (string_length > 0);
-            for (i=0; i < string_length; i++) {
-               if (! isprint((int) string[i])) {
-                  printable = FALSE;
-                  copy[i] = ' ';
-               }
-               else if ((string[i] == '\n') ||
-                        (string[i] == '\r') ||
-                        (string[i] == '\f'))
-                  copy[i] = ' ';
-               else
-                  copy[i] = string[i];
-            }
-            copy[i] = '\0';
-
-            if (printable) {
-               (void) fprintf(file_pointer, " string = \"%s\"", copy);
-            }
-            else if (!done_already && element_length < 2048) {
-                /* If unknown length print as a series of bytes.
-                 */
-                string = acr_get_element_data(cur_element);
-                fprintf(file_pointer, " byte = ");
-                for (i = 0; i < element_length; i++) {
-                    fprintf(file_pointer, "0x%02x", 
-                            (unsigned char)string[i]);
-                    if (i != element_length - 1) {
-                        fprintf(file_pointer, ", ");
-                    }
-                }
-            }
-            free(copy);
-         }
+         maybe_print_as_string(file_pointer, cur_element, element_length, 
+                               done_already);
 
          /* End line */
          (void) fprintf(file_pointer, "\n");
