@@ -7,6 +7,18 @@
    @CREATED    : January 28, 1997 (Peter Neelin)
    @MODIFIED   : 
    * $Log: dicom_read.c,v $
+   * Revision 1.27  2008/01/13 09:38:54  stever
+   * Avoid compiler warnings about functions and variables that are defined
+   * but not used.  Remove some such functions and variables,
+   * conditionalize some, and move static declarations out of header files
+   * into C files.
+   *
+   * Revision 1.26  2008/01/11 07:17:07  stever
+   * Remove unused variables.
+   *
+   * Revision 1.25  2007/12/09 19:52:15  alex
+   * Fixed error in echo_time extraction
+   *
    * Revision 1.24  2007/06/08 20:28:57  ilana
    * added several fields to mincheader (dicom elements and found in ASCONV header)
    *
@@ -206,7 +218,7 @@ static void get_coordinate_info(Acr_Group group_list, File_Info *file_info,
                                 double coordinate[WORLD_NDIMS]);
 static void get_general_header_info(Acr_Group group_list,
                                     General_Info *general_info);
-static void convert_numa3_coordinate(double coordinate[WORLD_NDIMS]);
+//static void convert_numa3_coordinate(double coordinate[WORLD_NDIMS]);
 static void get_identification_info(Acr_Group group_list, 
                                     double *study_id, int *acq_id, 
                                     int *rec_num, int *image_type);
@@ -972,7 +984,6 @@ acr_recursive_search(Acr_Element el_lst, int *nskip, Acr_Element_Id srch_id)
 {
     Acr_Element el_ret = NULL;
     Acr_Element el_tmp;
-    int i;
 
     for (el_tmp = el_lst; el_tmp != NULL; 
          el_tmp = acr_get_element_next(el_tmp)) {
@@ -1220,7 +1231,6 @@ get_coordinate_info(Acr_Group group_list,
 {
     Volume_Index ivolume;
     World_Index iworld;
-    Acr_Element element;
     int found_dircos[VOL_NDIMS];
     int found_coordinate;
     double frame_time;
@@ -1229,7 +1239,6 @@ get_coordinate_info(Acr_Group group_list,
     double largest;
     double psize[IMAGE_NDIMS];
     double slice_thickness, slice_spacing;
-    int result;
 
     double RowColVec[6]; /* row/column unit vectors in public dicom element */
 
@@ -1590,6 +1599,7 @@ get_coordinate_info(Acr_Group group_list,
 
 }
 
+#if 0
 /* ----------------------------- MNI Header -----------------------------------
    @NAME       : convert_numa3_coordinate
    @INPUT      : coordinate
@@ -1608,6 +1618,7 @@ convert_numa3_coordinate(double coordinate[WORLD_NDIMS])
     coordinate[XCOORD] = -coordinate[XCOORD];
     coordinate[ZCOORD] = -coordinate[ZCOORD];
 }
+#endif
 
 /* ----------------------------- MNI Header -----------------------------------
    @NAME       : convert_dicom_coordinate
@@ -1796,7 +1807,7 @@ get_general_header_info(Acr_Group group_list, General_Info *gi_ptr)
     if (gi_ptr->acq.echo_time != -DBL_MAX)
         gi_ptr->acq.echo_time /= 1000.0;
 
-    gi_ptr->acq.echo_time = 
+    gi_ptr->acq.echo_train_length = 
         acr_find_double(group_list, ACR_Echo_train_length, -DBL_MAX); /*added echo train length ilana*/
     
     gi_ptr->acq.echo_number = 
