@@ -7,6 +7,21 @@
 @CREATED    : January 28, 1997 (Peter Neelin)
 @MODIFIED   : 
  * $Log: dicom_to_minc.h,v $
+ * Revision 1.9  2007/06/08 20:28:57  ilana
+ * added several fields to mincheader (dicom elements and found in ASCONV header)
+ *
+ * Revision 1.8  2006/04/09 15:33:10  bert
+ * Add flags and fields for DTI
+ *
+ * Revision 1.7  2005/11/04 22:25:34  bert
+ * Change COORDINATE_EPSILON again, now set to 0.005
+ *
+ * Revision 1.6  2005/10/26 23:43:55  bert
+ * Fix COORDINATE_EPSILON at 0.0001
+ *
+ * Revision 1.5  2005/07/14 19:00:30  bert
+ * Changes ported from 1.X branch
+ *
  * Revision 1.4.2.2  2005/06/20 22:00:26  bert
  * Simplify Image_Data structure, add is_siemens_mosaic() function declaration
  *
@@ -85,7 +100,7 @@
 #define HOURS_PER_DAY 24
 #define SECONDS_PER_DAY (HOURS_PER_DAY*SECONDS_PER_HOUR)
 #define MS_PER_SECOND 1000
-#define COORDINATE_EPSILON (100.0*FLT_EPSILON)
+#define COORDINATE_EPSILON (0.005) /* bert- relaxed from 1.0e-5 */
 
 /* Default value for ncopts */
 #define NCOPTS_DEFAULT NC_VERBOSE
@@ -158,6 +173,7 @@ typedef struct {
         string_t reg_date;
         string_t reg_time;
         double weight;
+	string_t position; /*added ilana*/
     } patient;
     struct {
         string_t start_time;
@@ -168,6 +184,7 @@ typedef struct {
         string_t software_version;
         string_t serial_no;
         string_t calibration_date;
+	string_t calibration_time;
         string_t institution;
         string_t station_id;
         string_t referring_physician;
@@ -179,15 +196,22 @@ typedef struct {
     } study;
     struct {
         string_t scan_seq;
+	string_t acquisition_time; /*added by ilana*/
+	string_t image_time; /*added by ilana*/
+	string_t series_time; /*added by ilana*/
         string_t protocol_name;
+	string_t series_description; /*added by ilana*/
         string_t receive_coil;
         string_t transmit_coil;
         double rep_time;
         double slice_thickness;
         double num_slices;
+	string_t slice_order;
         double echo_time;
+	double echo_train_length; /*added by ilana*/
         double echo_number;
         double inv_time;
+	double delay_in_TR; /*added by ilana*/
         double b_value;
         double flip_angle;
         double num_avg;
@@ -206,6 +230,7 @@ typedef struct {
         double  sar;
         string_t comments;
         char *MrProt;           // Siemens Numaris 4 specific
+        short dti;              /* TRUE if we think this is DTI */
     } acq;
     Acr_Group group_list;
 } General_Info;
@@ -224,6 +249,8 @@ typedef struct {
    double window_min;
    double coordinate[MRI_NDIMS];
    double width[MRI_NDIMS];     /* Sample width along each MRI dimension */
+   double b_value;              /* DTI b-value, if present */
+   double grad_direction[WORLD_NDIMS]; /* DTI gradient direction */
 } File_Info;
 
 /* Structure for storing the actual image data */
