@@ -7,6 +7,20 @@
    @CREATED    : January 28, 1997 (Peter Neelin)
    @MODIFIED   : 
    * $Log: minc_file.c,v $
+   * Revision 1.17  2008/01/17 02:33:01  rotor
+   *  * removed all rcsids
+   *  * removed a bunch of ^L's that somehow crept in
+   *  * removed old (and outdated) BUGS file
+   *
+   * Revision 1.16  2008/01/12 19:08:14  stever
+   * Add __attribute__ ((unused)) to all rcsid variables.
+   *
+   * Revision 1.15  2008/01/11 07:17:07  stever
+   * Remove unused variables.
+   *
+   * Revision 1.14  2007/12/18 15:19:48  jharlap
+   * reverted acq.comments from its new image_comments name to maintain backwards compatibility.  also restored all the dicom elements which ilana decided to remove, with the exception of 0-length elements which make HDF spit out lots of warnings
+   *
    * Revision 1.13  2007/06/08 20:28:57  ilana
    * added several fields to mincheader (dicom elements and found in ASCONV header)
    *
@@ -134,10 +148,8 @@
    software for any purpose.  It is provided "as is" without
    express or implied warranty.
 ---------------------------------------------------------------------------- */
-static const char rcsid[] = "$Header: /private-cvsroot/minc/conversion/dcm2mnc/minc_file.c,v 1.13 2007/06/08 20:28:57 ilana Exp $";
 
 #include "dcm2mnc.h"
-
 #include <sys/stat.h>
 
 /* Define mri dimension names */
@@ -327,10 +339,6 @@ create_minc_file(const char *minc_file,
     int mincid, icvid;
     static char full_path[1024];
 
-    /* Prefixes for creating file name */
-    static char *scan_prefix[MRI_NDIMS] = 
-        {"sl", "e", "d", "p", "cs"};
-
     /* Turn off fatal errors */
     ncopts = NCOPTS_DEFAULT;
 
@@ -585,8 +593,6 @@ void setup_minc_variables(int mincid, General_Info *general_info,
     int varid, imgid, dicomvar;
     double valid_range[2];
     char name[MAX_NC_NAME];
-    int index;
-    int regular;
     Acr_Group cur_group;
     Acr_Element cur_element;
     int length;
@@ -945,7 +951,7 @@ void setup_minc_variables(int mincid, General_Info *general_info,
                     general_info->acq.image_type);
 
     if (strlen(general_info->acq.comments) > 0)
-        miattputstr(mincid, varid, "image_comments", 
+        miattputstr(mincid, varid, MIcomments,
                     general_info->acq.comments);
 
     // this is Siemens Numaris 4 specific!
@@ -983,24 +989,25 @@ void setup_minc_variables(int mincid, General_Info *general_info,
     been included in the minc fields, we just should add those that
     are missing and might be of use. Removing the fields starting with
     "dicom_0x... for now   ilana*/
-    /*cur_group = general_info->group_list;
+    /* contrary to ilanas view - this *is* useful info! */
+    cur_group = general_info->group_list;
     dicomvar = ncvardef(mincid, DICOM_ROOT_VAR, NC_LONG, 0, NULL);
     miattputstr(mincid, dicomvar, MIvartype, MI_GROUP);
     miattputstr(mincid, dicomvar, MIvarid, "MNI DICOM variable");
-    miadd_child(mincid, ncvarid(mincid, MIrootvariable), dicomvar);*/
+    miadd_child(mincid, ncvarid(mincid, MIrootvariable), dicomvar);
 
     
-    /*while (cur_group != NULL) {*/
+    while (cur_group != NULL) {
 
         /* Create variable for group */
-        /*sprintf(name, "dicom_0x%04x", acr_get_group_group(cur_group));
+        sprintf(name, "dicom_0x%04x", acr_get_group_group(cur_group));
         varid = ncvardef(mincid, name, NC_LONG, 0, NULL);
         miattputstr(mincid, varid, MIvartype, MI_GROUP);
         miattputstr(mincid, varid, MIvarid, "MNI DICOM variable");
-        miadd_child(mincid, dicomvar, varid);*/
+        miadd_child(mincid, dicomvar, varid);
 
         /* Loop through elements of group */
-        /*cur_element = acr_get_group_element_list(cur_group);
+        cur_element = acr_get_group_element_list(cur_group);
         while (cur_element != NULL) {
             sprintf(name, "el_0x%04x", 
                     acr_get_element_element(cur_element));
@@ -1020,12 +1027,15 @@ void setup_minc_variables(int mincid, General_Info *general_info,
                 datatype = NC_CHAR;
             else
                 datatype = NC_BYTE;
-            ncattput(mincid, varid, name, datatype, length, data);
+
+            /* Do not insert 0-length elements as it makes HDF complain */
+            if(length > 0)
+                ncattput(mincid, varid, name, datatype, length, data);
          
             cur_element = acr_get_element_next(cur_element);
         }
         cur_group = acr_get_group_next(cur_group);
-    }*/
+    }
 
     /* Create the history attribute */
     if (G.minc_history != NULL) {
