@@ -5,6 +5,13 @@
 @CREATED    : Jul 2006 (Leila Baghdadi)
 @MODIFIED   : 
  * $Log: vff2mnc.c,v $
+ * Revision 1.4  2008/01/11 07:17:07  stever
+ * Remove unused variables.
+ *
+ * Revision 1.3  2007/12/11 12:43:01  rotor
+ *  * added static to all global variables in main programs to avoid linking
+ *       problems with libraries (compress in mincconvert and libz for example)
+ *
  * Revision 1.2  2007/01/19 17:52:56  baghdadi
  * Added minor revision for string manipulations.
  *
@@ -25,8 +32,8 @@
 #include <windows.h>
 #endif
 
+#include <time_stamp.h>
 #include <ParseArgv.h>
-#include <../dcm2mnc/string_to_filename.h>
 
 
 /* Function Prototypes */
@@ -55,7 +62,7 @@ struct globals G;
 
 #define VERSION_STRING "2.0.12 built " __DATE__ " " __TIME__
 
-ArgvInfo argTable[] = {
+static ArgvInfo argTable[] = {
     {NULL, ARGV_VERINFO, VERSION_STRING, NULL, NULL },
     {"-noswap", ARGV_CONSTANT, (char *) FALSE, (char *) &G.little_endian,
      "Change to noswap default is swap"},
@@ -477,9 +484,7 @@ read_2Dvff_files_header(const char **file_list, int num_files,
   char temp[10];
   char *pch;
   long rawsize;
-  long count;
   
-  int r;
   double element_size = 1;
   
   m2->mnc_steps[0] = 1;
@@ -700,7 +705,6 @@ read_3Dvff_file_header(char *filename, struct mnc_vars *m2, struct vff_attrs *va
   char linebuf[1024];
   char temp[20];
   
-  int r;
   double element_size;
   char *pch;
   int counter;
@@ -854,7 +858,7 @@ read_3Dvff_file_image(mihandle_t hvol, char *filename,
 		      double range[2])
 {
   FILE *fp ;
-  int i,j,counts,r;
+  int i,counts,r;
   void *buffer;
   int number_of_bits = vattrs.bits/8;
   unsigned long start[MAX_VFF_DIMS]; /* MINC data starts */
