@@ -19,11 +19,26 @@
 @CREATED    : July 24, 1992. (Peter Neelin, Montreal Neurological Institute)
 @MODIFIED   : 
  * $Log: minc.h,v $
- * Revision 6.11.2.2  2004/09/28 20:23:40  bert
- * Minor portability fixes for Windows
+ * Revision 6.18  2007/08/09 17:05:25  rotor
+ *  * added some fixes of Claudes for chunking and internal compression
  *
- * Revision 6.11.2.1  2004/08/11 21:03:06  bert
- * Fix MI_MAX_IMGDIMS at 100 to avoid netCDF 3.5.1 problem
+ * Revision 6.17  2005/08/26 21:04:57  bert
+ * Use #if rather than #ifdef with MINC2 symbol
+ *
+ * Revision 6.16  2004/12/03 21:52:35  bert
+ * Minor changes for Windows build
+ *
+ * Revision 6.15  2004/10/15 13:48:13  bert
+ * Minor changes for Windows compatibility
+ *
+ * Revision 6.14  2004/08/11 20:50:54  bert
+ * Fix incompatibility with netCDF 3.5.1 by fixing MI_MAX_IMGDIMS at 100
+ *
+ * Revision 6.13  2004/06/04 18:14:52  bert
+ * Add micreate_ident()
+ *
+ * Revision 6.12  2004/04/27 15:44:04  bert
+ * Add MINC 2.0 specific stuff
  *
  * Revision 6.11  2004/04/15 21:13:21  bert
  * Add C++ linkage specifier
@@ -125,7 +140,7 @@
               make no representations about the suitability of this
               software for any purpose.  It is provided "as is" without
               express or implied warranty.
-@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc.h,v 6.11.2.2 2004/09/28 20:23:40 bert Exp $ MINC (MNI)
+@RCSID      : $Header: /private-cvsroot/minc/libsrc/minc.h,v 6.18 2007/08/09 17:05:25 rotor Exp $ MINC (MNI)
 ---------------------------------------------------------------------------- */
 
 #include <netcdf.h>
@@ -446,7 +461,6 @@ extern "C" {
 #define MI_ERR_UNCOMPRESS       1349  /* Not able to uncompress file */
 
 /* MINC public functions */
-
 #ifndef MNCAPI
 #if defined(_MSC_VER)
 /* If we are building on the Microsoft C compiler, we want to
@@ -516,6 +530,7 @@ MNCAPI int micreate_std_variable(int cdfid, char *name, nc_type datatype,
 MNCAPI int micreate_group_variable(int cdfid, char *name);
 MNCAPI const char *miget_version(void);
 MNCAPI int miappend_history(int fd, const char *tm_stamp);
+MNCAPI int micreate_ident(char * id_str, size_t length);
 
 /* From image_conversion.c */
 MNCAPI int miicv_create(void);
@@ -536,6 +551,49 @@ MNCAPI int miicv_put(int icvid, long start[], long count[], void *values);
 /* From dim_conversion.c */
 MNCAPI int miicv_attach(int icvid, int cdfid, int varid);
 
+/* From minc_error.c */
+MNCAPI void milog_init(const char *);
+MNCAPI int milog_set_verbosity(int);
+
+#if MINC2
+
+/* New functions, not directly part of compatibility layer. */
+extern int MI2varsize(int fd, int varid, long *size_ptr);
+
+#define MI2_GRPNAME "/minc-2.0"
+/* These must not interfere with any NC_ flags we might have to support. */
+#define MI2_CREATE_V2 0x1000    /* Force V2 format */
+#define MI2_CREATE_V1 0x2000    /* Force V1 format */
+
+/* Possible compression type values. */
+#define MI2_COMP_UNKNOWN (-1)
+#define MI2_COMP_NONE 0
+#define MI2_COMP_ZLIB 1
+
+#define MI2_CHUNK_UNKNOWN (-1)
+#define MI2_CHUNK_OFF 0
+#define MI2_CHUNK_ON 1
+#define MI2_CHUNK_MIN_SIZE 4
+
+#define MI2_OPTS_V1 1
+
+struct mi2opts {
+    int struct_version;
+    int comp_type;
+    int comp_param;
+    int chunk_type;
+    int chunk_param;
+};
+
+#include <hdf5.h>
+#include "minc_compat.h"
+
+#define MI2_ISH5OBJ(x) (H5Iget_type(x) > 0)
+
+#else
+#define MI2_ISH5OBJ(x) (0)
+#endif /* MINC2 */
+
 #ifdef __cplusplus
 }
 #endif /* __cplusplus */
