@@ -10,6 +10,18 @@
 @CREATED    : March 31, 1995 (Peter Neelin)
 @MODIFIED   : 
  * $Log: minc_modify_header.c,v $
+ * Revision 6.13  2008/01/17 02:33:02  rotor
+ *  * removed all rcsids
+ *  * removed a bunch of ^L's that somehow crept in
+ *  * removed old (and outdated) BUGS file
+ *
+ * Revision 6.12  2008/01/12 19:08:15  stever
+ * Add __attribute__ ((unused)) to all rcsid variables.
+ *
+ * Revision 6.11  2007/12/11 12:43:01  rotor
+ *  * added static to all global variables in main programs to avoid linking
+ *       problems with libraries (compress in mincconvert and libz for example)
+ *
  * Revision 6.10  2004/11/01 22:38:38  bert
  * Eliminate all references to minc_def.h
  *
@@ -77,10 +89,6 @@
               express or implied warranty.
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/minc_modify_header/minc_modify_header.c,v 6.10 2004/11/01 22:38:38 bert Exp $";
-#endif
-
 #include "config.h"
 #include <stdlib.h>
 #include <stdio.h>
@@ -126,7 +134,7 @@ struct {
 } *attribute_list = NULL;
 
 /* Argument table */
-ArgvInfo argTable[] = {
+static ArgvInfo argTable[] = {
    {NULL, ARGV_HELP, NULL, NULL,
        "Options for specifying attribute values by name."},
    {"-sinsert", ARGV_FUNC, (char *) get_attribute, NULL,
