@@ -10,6 +10,21 @@
 @CREATED    : April 28, 1995 (Peter Neelin)
 @MODIFIED   : 
  * $Log: mincmath.c,v $
+ * Revision 6.14  2008/01/17 02:33:02  rotor
+ *  * removed all rcsids
+ *  * removed a bunch of ^L's that somehow crept in
+ *  * removed old (and outdated) BUGS file
+ *
+ * Revision 6.13  2008/01/13 04:30:28  stever
+ * Add braces around static initializers.
+ *
+ * Revision 6.12  2008/01/12 19:08:15  stever
+ * Add __attribute__ ((unused)) to all rcsid variables.
+ *
+ * Revision 6.11  2007/12/11 12:43:01  rotor
+ *  * added static to all global variables in main programs to avoid linking
+ *       problems with libraries (compress in mincconvert and libz for example)
+ *
  * Revision 6.10  2005/08/26 21:07:17  bert
  * Use #if rather than #ifdef with MINC2 symbol, and be sure to include config.h whereever MINC2 is used
  *
@@ -80,10 +95,6 @@
  *
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincmath/mincmath.c,v 6.10 2005/08/26 21:07:17 bert Exp $";
-#endif
-
 #define _GNU_SOURCE 1
 #if HAVE_CONFIG_H
 #include "config.h"
@@ -130,37 +141,37 @@ typedef enum {
 /* Table that matches [Operation][Number of constants (0,1,2)] to a number
    of volume operands */
 Num_Operands OperandTable[][3] = {
-   ILLEGAL_NUMOP, ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* UNSPECIFIED_OP */
-   NARY_NUMOP,    UNARY_NUMOP,   ILLEGAL_NUMOP,       /* ADD_OP */
-   BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP,       /* SUB_OP */
-   NARY_NUMOP,    UNARY_NUMOP,   ILLEGAL_NUMOP,       /* MULT_OP */
-   BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP,       /* DIV_OP */
-   UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* SQRT_OP */
-   UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* SQUARE_OP */
-   ILLEGAL_NUMOP, UNARY_NUMOP,   UNARY_NUMOP,         /* SCALE_OP */
-   ILLEGAL_NUMOP, ILLEGAL_NUMOP, UNARY_NUMOP,         /* CLAMP_OP */
-   ILLEGAL_NUMOP, ILLEGAL_NUMOP, UNARY_NUMOP,         /* SEGMENT_OP */
-   ILLEGAL_NUMOP, ILLEGAL_NUMOP, UNARY_NUMOP,         /* NSEGMENT_OP */
-   BINARY_NUMOP,  BINARY_NUMOP,  ILLEGAL_NUMOP,       /* PERCENTDIFF_OP */
-   BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP,       /* EQ_OP */
-   BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP,       /* NE_OP */
-   BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP,       /* GT_OP */
-   BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP,       /* GE_OP */
-   BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP,       /* LT_OP */
-   BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP,       /* LE_OP */
-   NARY_NUMOP,    ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* AND_OP */
-   NARY_NUMOP,    ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* OR_OP */
-   UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* NOT_OP */
-   UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* ISNAN_OP */
-   UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* NISNAN_OP */
-   UNARY_NUMOP,   UNARY_NUMOP,   ILLEGAL_NUMOP,       /* INVERT_OP */
-   UNARY_NUMOP,   UNARY_NUMOP,   UNARY_NUMOP,         /* EXP_OP */
-   UNARY_NUMOP,   UNARY_NUMOP,   UNARY_NUMOP,         /* LOG_OP */
-   NARY_NUMOP,    ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* MAX_OP */
-   NARY_NUMOP,    ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* MIN_OP */
-   UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* ABS_OP */
-   NARY_NUMOP,    ILLEGAL_NUMOP, ILLEGAL_NUMOP,       /* COUNT_OP */
-   ILLEGAL_NUMOP, ILLEGAL_NUMOP, ILLEGAL_NUMOP        /* nothing */
+   { ILLEGAL_NUMOP, ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* UNSPECIFIED_OP */
+   { NARY_NUMOP,    UNARY_NUMOP,   ILLEGAL_NUMOP },     /* ADD_OP */
+   { BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP },     /* SUB_OP */
+   { NARY_NUMOP,    UNARY_NUMOP,   ILLEGAL_NUMOP },     /* MULT_OP */
+   { BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP },     /* DIV_OP */
+   { UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* SQRT_OP */
+   { UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* SQUARE_OP */
+   { ILLEGAL_NUMOP, UNARY_NUMOP,   UNARY_NUMOP },       /* SCALE_OP */
+   { ILLEGAL_NUMOP, ILLEGAL_NUMOP, UNARY_NUMOP },       /* CLAMP_OP */
+   { ILLEGAL_NUMOP, ILLEGAL_NUMOP, UNARY_NUMOP },       /* SEGMENT_OP */
+   { ILLEGAL_NUMOP, ILLEGAL_NUMOP, UNARY_NUMOP },       /* NSEGMENT_OP */
+   { BINARY_NUMOP,  BINARY_NUMOP,  ILLEGAL_NUMOP },     /* PERCENTDIFF_OP */
+   { BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP },     /* EQ_OP */
+   { BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP },     /* NE_OP */
+   { BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP },     /* GT_OP */
+   { BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP },     /* GE_OP */
+   { BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP },     /* LT_OP */
+   { BINARY_NUMOP,  UNARY_NUMOP,   ILLEGAL_NUMOP },     /* LE_OP */
+   { NARY_NUMOP,    ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* AND_OP */
+   { NARY_NUMOP,    ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* OR_OP */
+   { UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* NOT_OP */
+   { UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* ISNAN_OP */
+   { UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* NISNAN_OP */
+   { UNARY_NUMOP,   UNARY_NUMOP,   ILLEGAL_NUMOP },     /* INVERT_OP */
+   { UNARY_NUMOP,   UNARY_NUMOP,   UNARY_NUMOP },       /* EXP_OP */
+   { UNARY_NUMOP,   UNARY_NUMOP,   UNARY_NUMOP },       /* LOG_OP */
+   { NARY_NUMOP,    ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* MAX_OP */
+   { NARY_NUMOP,    ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* MIN_OP */
+   { UNARY_NUMOP,   ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* ABS_OP */
+   { NARY_NUMOP,    ILLEGAL_NUMOP, ILLEGAL_NUMOP },     /* COUNT_OP */
+   { ILLEGAL_NUMOP, ILLEGAL_NUMOP, ILLEGAL_NUMOP }      /* nothing */
 };
 
 /* Structure for window information */
@@ -197,29 +208,29 @@ static void end_math(void *caller_data, long num_voxels,
 static char **read_file_names(char *filelist, int *num_files);
 
 /* Argument variables */
-int clobber = FALSE;
-int verbose = TRUE;
-int debug = FALSE;
-nc_type datatype = MI_ORIGINAL_TYPE;
-int is_signed = FALSE;
-double valid_range[2] = {0.0, 0.0};
-int copy_all_header = DEFAULT_BOOL;
-char *loop_dimension = NULL;
-int max_buffer_size_in_kb = 4 * 1024;
-double constant = DEFAULT_DBL;
-double constant2[2] = {DEFAULT_DBL, DEFAULT_DBL};
-Operation operation = UNSPECIFIED_OP;
-int propagate_nan = TRUE;
-int use_nan_for_illegal_values = TRUE;
-double value_for_illegal_operations = DEFAULT_DBL;
-int check_dim_info = TRUE;
-char *filelist = NULL;
+static int clobber = FALSE;
+static int verbose = TRUE;
+static int debug = FALSE;
+static nc_type datatype = MI_ORIGINAL_TYPE;
+static int is_signed = FALSE;
+static double valid_range[2] = {0.0, 0.0};
+static int copy_all_header = DEFAULT_BOOL;
+static char *loop_dimension = NULL;
+static int max_buffer_size_in_kb = 4 * 1024;
+static double constant = DEFAULT_DBL;
+static double constant2[2] = {DEFAULT_DBL, DEFAULT_DBL};
+static Operation operation = UNSPECIFIED_OP;
+static int propagate_nan = TRUE;
+static int use_nan_for_illegal_values = TRUE;
+static double value_for_illegal_operations = DEFAULT_DBL;
+static int check_dim_info = TRUE;
+static char *filelist = NULL;
 #if MINC2
-int minc2_format = FALSE;
+static int minc2_format = FALSE;
 #endif /* MINC2 */
 
 /* Argument table */
-ArgvInfo argTable[] = {
+static ArgvInfo argTable[] = {
    {NULL, ARGV_HELP, (char *) NULL, (char *) NULL, 
        "General options:"},
 #if MINC2
