@@ -6,6 +6,29 @@
 @CREATED    : February 8, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: resample_volumes.c,v $
+ * Revision 6.12  2008/01/17 02:33:02  rotor
+ *  * removed all rcsids
+ *  * removed a bunch of ^L's that somehow crept in
+ *  * removed old (and outdated) BUGS file
+ *
+ * Revision 6.11  2008/01/13 09:49:00  stever
+ * Add do_Ncubic_interpolation declaration, moved here from mincresample.h.
+ *
+ * Revision 6.10  2008/01/13 09:38:54  stever
+ * Avoid compiler warnings about functions and variables that are defined
+ * but not used.  Remove some such functions and variables,
+ * conditionalize some, and move static declarations out of header files
+ * into C files.
+ *
+ * Revision 6.9  2008/01/12 19:08:15  stever
+ * Add __attribute__ ((unused)) to all rcsid variables.
+ *
+ * Revision 6.8  2008/01/11 07:17:08  stever
+ * Remove unused variables.
+ *
+ * Revision 6.7  2007/12/12 20:55:26  rotor
+ *  * added a bunch of bug fixes from Claude.
+ *
  * Revision 6.6  2006/05/19 00:13:39  bert
  * Add config.h
  *
@@ -92,10 +115,6 @@
               express or implied warranty.
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincresample/resample_volumes.c,v 6.6 2006/05/19 00:13:39 bert Exp $";
-#endif
-
 #if HAVE_CONFIG_H
 #include "config.h"
 #endif
@@ -109,6 +128,19 @@ static char rcsid[]="$Header: /private-cvsroot/minc/progs/mincresample/resample_
 #include <volume_io.h>
 #include "mincresample.h"
 
+static void load_volume(File_Info *file, long start[], long count[],
+                        Volume_Data *volume);
+static void get_slice(long slice_num, VVolume *in_vol, VVolume *out_vol,
+                      General_transform *transformation,
+                      double *minimum, double *maximum);
+static void renormalize_slices(Program_Flags *program_flags, VVolume *out_vol,
+                               double slice_min[], double slice_max[]);
+static int do_Ncubic_interpolation(Volume_Data *volume, 
+                                   long index[], int cur_dim, 
+                                   double frac[], double *result);
+
+
+
 /* ----------------------------- MNI Header -----------------------------------
 @NAME       : resample_volumes
 @INPUT      : program_flags - data for program execution
@@ -680,17 +712,29 @@ int tricubic_interpolant(Volume_Data *volume,
    slcmax = volume->size[SLC_AXIS] - 1;
    rowmax = volume->size[ROW_AXIS] - 1;
    colmax = volume->size[COL_AXIS] - 1;
-   if ((coord[SLICE]  < 0) || (coord[SLICE]  > slcmax) ||
-       (coord[ROW]    < 0) || (coord[ROW]    > rowmax) ||
-       (coord[COLUMN] < 0) || (coord[COLUMN] > colmax)) {
-      *result = volume->fillvalue;
-      return FALSE;
+
+   /* Identify a slice or a volume. Slice must be in x-y. */
+   if( slcmax == 0 ) {
+     /* 2-d slice */
+     if( (coord[ROW] < 0) || (coord[ROW] > rowmax) ||
+         (coord[COLUMN] < 0) || (coord[COLUMN] > colmax) ) {
+       *result = volume->fillvalue;
+       return FALSE;
+     }
+   } else {
+     /* 3-d volume */
+     if( (coord[SLICE]  < 0) || (coord[SLICE]  > slcmax) ||
+         (coord[ROW]    < 0) || (coord[ROW]    > rowmax) ||
+         (coord[COLUMN] < 0) || (coord[COLUMN] > colmax) ) {
+       *result = volume->fillvalue;
+       return FALSE;
+     }
    }
 
    /* Get the whole and fractional part of the coordinate */
-   slcind = (long) coord[SLICE];
-   rowind = (long) coord[ROW];
-   colind = (long) coord[COLUMN];
+   slcind = (long)coord[SLICE];
+   rowind = (long)coord[ROW];
+   colind = (long)coord[COLUMN];
    frac[0] = coord[SLICE]  - slcind;
    frac[1] = coord[ROW]    - rowind;
    frac[2] = coord[COLUMN] - colind;
@@ -698,16 +742,39 @@ int tricubic_interpolant(Volume_Data *volume,
    rowind--;
    colind--;
 
-   /* Check for edges - do linear interpolation at edges */
+   /* Check for dimension of image. */
+
+   /* Check for edges in the 2-d plane - do linear interpolation at edges */
+   /* Note: Spline stencil is right-sided, so ok to start at 0. */
+   if( slcmax == 0 && rowmax > 0 && colmax > 0 ) {
+     if( (rowind > rowmax-3) || (rowind < 0) ||
+         (colind > colmax-3) || (colind < 0)) {
+       return trilinear_interpolant(volume, coord, result);
+     } else {
+       slcind = 0;  /* there is only slice 0 */
+       index[0]=slcind; index[1]=rowind; index[2]=colind;
+       if( do_Ncubic_interpolation(volume, index, 1, frac, result) ) {
+         /* scaling not done for a slice in do_Ncubic_interpolation, */
+         /* only done for a volume */
+         *result = (*result) * volume->scale[slcind] + volume->offset[slcind];
+         return TRUE;
+       } else {
+         return FALSE;
+       }
+     }
+   }
+
+   /* Check for edges in the 3-d volume - do linear interpolation at edges */
+   /* Note: Spline stencil is right-sided, so ok to start at 0. */
    if ((slcind > slcmax-3) || (slcind < 0) ||
        (rowind > rowmax-3) || (rowind < 0) ||
        (colind > colmax-3) || (colind < 0)) {
       return trilinear_interpolant(volume, coord, result);
+   } else {
+     index[0]=slcind; index[1]=rowind; index[2]=colind;
+     /* Do the interpolation and return its value */
+     return do_Ncubic_interpolation(volume, index, 0, frac, result);
    }
-   index[0]=slcind; index[1]=rowind; index[2]=colind;
-
-   /* Do the interpolation and return its value */
-   return do_Ncubic_interpolation(volume, index, 0, frac, result);
 
 }
 
@@ -757,6 +824,7 @@ int do_Ncubic_interpolation(Volume_Data *volume,
           (v3 < volume->vrange[0]) || (v3 > volume->vrange[1])) {
          found_fillvalue = TRUE;
       }
+
    }
 
    /* Otherwise, recurse */
@@ -914,7 +982,6 @@ static double
 sinc_mac_d(Volume_Data *volume, int z, int y, int x, double *win_ptr)
 {
     double result;
-    double value;
     long offset;
     double *pix_ptr;
 
@@ -931,7 +998,6 @@ static double
 sinc_mac_f(Volume_Data *volume, int z, int y, int x, double *win_ptr)
 {
     double result;
-    double value;
     long offset;
     float *pix_ptr;
 
@@ -948,7 +1014,6 @@ static double
 sinc_mac_uc(Volume_Data *volume, int z, int y, int x, double *win_ptr)
 {
     double result;
-    double value;
     double slope = volume->scale[z];
     double intercept = volume->offset[z];
     long offset;
@@ -967,7 +1032,6 @@ static double
 sinc_mac_sc(Volume_Data *volume, int z, int y, int x, double *win_ptr)
 {
     double result;
-    double value;
     double slope = volume->scale[z];
     double intercept = volume->offset[z];
     long offset;
@@ -986,7 +1050,6 @@ static double
 sinc_mac_us(Volume_Data *volume, int z, int y, int x, double *win_ptr)
 {
     double result;
-    double value;
     double slope = volume->scale[z];
     double intercept = volume->offset[z];
     long offset;
@@ -1005,7 +1068,6 @@ static double
 sinc_mac_ss(Volume_Data *volume, int z, int y, int x, double *win_ptr)
 {
     double result;
-    double value;
     double slope = volume->scale[z];
     double intercept = volume->offset[z];
     long offset;
@@ -1024,7 +1086,6 @@ static double
 sinc_mac_ui(Volume_Data *volume, int z, int y, int x, double *win_ptr)
 {
     double result;
-    double value;
     double slope = volume->scale[z];
     double intercept = volume->offset[z];
     long offset;
@@ -1043,7 +1104,6 @@ static double
 sinc_mac_si(Volume_Data *volume, int z, int y, int x, double *win_ptr)
 {
     double result;
-    double value;
     double slope = volume->scale[z];
     double intercept = volume->offset[z];
     long offset;
@@ -1080,7 +1140,7 @@ windowed_sinc_interpolant(Volume_Data *volume, Coord_Vector coord,
     double zt, yt, xt;
     double zf, yf, xf;
     int zi, yi, xi;
-    int i, j, k;
+    int i, j;
     double new;
     double tmp;
     long slcmax, rowmax, colmax;
