@@ -11,6 +11,20 @@
 @CREATED    : September 25, 1992 (Peter Neelin)
 @MODIFIED   : 
  * $Log: rawtominc.c,v $
+ * Revision 6.28  2008/01/17 02:33:06  rotor
+ *  * removed all rcsids
+ *  * removed a bunch of ^L's that somehow crept in
+ *  * removed old (and outdated) BUGS file
+ *
+ * Revision 6.27  2008/01/13 04:30:28  stever
+ * Add braces around static initializers.
+ *
+ * Revision 6.26  2008/01/12 19:08:15  stever
+ * Add __attribute__ ((unused)) to all rcsid variables.
+ *
+ * Revision 6.25  2008/01/11 07:17:08  stever
+ * Remove unused variables.
+ *
  * Revision 6.24  2007/02/20 18:24:45  baghdadi
  * make sure the global scaling happens when input is float and output is float or double
  *
@@ -160,10 +174,6 @@
               express or implied warranty.
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/rawtominc/rawtominc.c,v 6.24 2007/02/20 18:24:45 baghdadi Exp $";
-#endif
-
 #include "config.h"
 #include <stdlib.h>
 #include <stdio.h>
@@ -325,9 +335,9 @@ int ovrange_set;
 double dimstep[3] = {DEF_STEP, DEF_STEP, DEF_STEP};
 double dimstart[3] = {DEF_START, DEF_START, DEF_START};
 double dimdircos[3][3] = {
-   DEF_DIRCOS, DEF_DIRCOS, DEF_DIRCOS,
-   DEF_DIRCOS, DEF_DIRCOS, DEF_DIRCOS,
-   DEF_DIRCOS, DEF_DIRCOS, DEF_DIRCOS
+    { DEF_DIRCOS, DEF_DIRCOS, DEF_DIRCOS },
+    { DEF_DIRCOS, DEF_DIRCOS, DEF_DIRCOS },
+    { DEF_DIRCOS, DEF_DIRCOS, DEF_DIRCOS }
 };
 double origin[3] = {DEF_ORIGIN, DEF_ORIGIN, DEF_ORIGIN};
 int vector_dimsize = -1;
@@ -1803,7 +1813,6 @@ static int get_model_file(char *dst, char *key, char *nextArg)
 {
   Volume_Definition *volume_def;
   File_Info file;
-  int i;
    /* Check for following argument */
    if (nextArg == NULL) {
       (void) fprintf(stderr, 
