@@ -10,6 +10,14 @@
 @CREATED    : September 13, 1993 (Peter Neelin)
 @MODIFIED   : 
  * $Log: transformtags.c,v $
+ * Revision 6.4  2008/01/17 02:33:06  rotor
+ *  * removed all rcsids
+ *  * removed a bunch of ^L's that somehow crept in
+ *  * removed old (and outdated) BUGS file
+ *
+ * Revision 6.3  2008/01/12 19:08:15  stever
+ * Add __attribute__ ((unused)) to all rcsid variables.
+ *
  * Revision 6.2  2004/11/01 22:38:39  bert
  * Eliminate all references to minc_def.h
  *
@@ -49,10 +57,6 @@
  * 
 ---------------------------------------------------------------------------- */
 
-#ifndef lint
-static char rcsid[]="$Header: /private-cvsroot/minc/progs/xfm/transformtags.c,v 6.2 2004/11/01 22:38:39 bert Exp $";
-#endif
-
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
