@@ -10,10 +10,10 @@ set -e
 # _t4.xfm is inverse of _t3
 
 cp $srcdir/t1.xfm _t1.xfm
-../xfminvert _t1.xfm _t2.xfm
+../xfminvert -clobber _t1.xfm _t2.xfm
 dd if=/dev/zero | ../rawtominc -vector 3 -byte -clobber _grid.mnc 8 8 8
 ./create_grid_xfm _grid.mnc _t3.xfm
-../xfminvert _t3.xfm _t4.xfm
+../xfminvert -clobber _t3.xfm _t4.xfm
 
 
 # Test primary transforms.
@@ -35,7 +35,7 @@ dd if=/dev/zero | ../rawtominc -vector 3 -byte -clobber _grid.mnc 8 8 8
 ../xfmconcat _t5.xfm _t6.xfm _t7.xfm
 ./test_xfm 10000 _t7.xfm
 
-../xfminvert _t7.xfm _t8.xfm
+../xfminvert -clobber _t7.xfm _t8.xfm
 ./test_xfm 10000 _t8.xfm
 
 ../xfmconcat _t8.xfm _t2.xfm _t4.xfm _t7.xfm _t9.xfm
