@@ -15,10 +15,6 @@
 #include  <internal_volume_io.h>
 #include  <minc.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Volumes/input_free.c,v 1.29 2004/10/04 20:23:52 bert Exp $";
-#endif
-
 #define  DEFAULT_SUFFIX  "fre"
 
 #define  NUM_BYTE_VALUES      256
