@@ -16,10 +16,6 @@
 #include  <limits.h>
 #include  <float.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Volumes/multidim_arrays.c,v 1.16 2004/10/04 20:23:52 bert Exp $";
-#endif
-
 /* ----------------------------- MNI Header -----------------------------------
 @NAME       : create_empty_multidim_array
 @INPUT      : n_dimensions
