@@ -16,10 +16,6 @@
 #include  <limits.h>
 #include  <float.h>
 
-#ifndef lint
-static char rcsid[] = "$Header: /private-cvsroot/minc/volume_io/Volumes/volumes.c,v 1.77 2007/09/13 01:31:38 rotor Exp $";
-#endif
-
 STRING   XYZ_dimension_names[] = { MIxspace, MIyspace, MIzspace };
 STRING   File_order_dimension_names[] = { "", "", "", "", "" };
 
